#!/usr/bin/env bash

COINS=(AION AUTO144_5 AUTO192_7 BEAM BTCZ BTG CTXC ETC ETH EXCC GRIN-C29M GRIN-C32 MWC-C29D MWC-C31 XSG YEC ZCL ZEL ZER)
# 0 - algo
# 1 - coin.
function algo_or_coin(){
    result=0
    for c in ${COINS[*]}; do
        if [ "$c" == "$LOLMINER_ALGO" ] ; then
            result=1
            break
        fi
    done
    echo $result
}

function miner_ver() {
	local MINER_VER=$LOLMINER_VER
	[[ -z $MINER_VER ]] && MINER_VER=$MINER_LATEST_VER
	echo $MINER_VER
}

function miner_config_echo() {
	local MINER_VER=`miner_ver`
	miner_echo_config_file "$MINER_DIR/$MINER_VER/lolminer.conf"
}

function miner_config_gen() {
	MINER_CONFIG="$MINER_DIR/$MINER_VER/lolminer.conf"
	GLOBAL_CONFIG="$MINER_DIR/$MINER_VER/global_config.conf"
	mkfile_from_symlink $MINER_CONFIG

	if [ -z $LOLMINER_ALGO ]; then
		coin="AUTO144_5"
	else
		coin=$LOLMINER_ALGO
	fi
	#
	if [[ $(algo_or_coin) -eq 0  ]]; then
		conf="--algo $coin\n"
	else
		conf="--coin $coin\n"
	fi
	local host_cnt=$(echo $LOLMINER_SERVER | wc -w)
	LOLMINER_SERVER=($LOLMINER_SERVER)
	LOLMINER_PORT=($LOLMINER_PORT)
	for ((i=0; i<$host_cnt; i++)); do
		#URL
		[[ ! -z ${LOLMINER_PORT[$i]} ]] && port=${LOLMINER_PORT[$i]}
		local url="${LOLMINER_SERVER[$i]}:$port"
		conf+="--pool $url\n"
		# WALLET
		conf+="--user $LOLMINER_TEMPLATE\n"
		# PASSWORD
		if [[ ! -z $LOLMINER_PASS ]]; then
			conf+="--pass $LOLMINER_PASS\n"
		fi
	done

	[[ ! -z $LOLMINER_WORKER ]] && conf+="--worker $LOLMINER_WORKER\n"

	# TLS and other options
	[[ $LOLMINER_TLS -eq 1 ]] && conf+="--tls 1\n"

	#dual algo
	if [[ -n $LOLMINER_ALGO2 ]]; then
		conf+="--dualmode $LOLMINER_ALGO2\n"
		local host_cnt2=$(echo $LOLMINER_SERVER2 | wc -w)
		LOLMINER_SERVER2=($LOLMINER_SERVER2)
		LOLMINER_PORT2=($LOLMINER_PORT2)
		for ((i=0; i<$host_cnt2; i++)); do
			#URL
			[[ ! -z ${LOLMINER_PORT2[$i]} ]] && port2=${LOLMINER_PORT2[$i]}
			local url2="${LOLMINER_SERVER2[$i]}:$port2"
			conf+="--dualpool $url2\n"
			# WALLET
			conf+="--dualuser $LOLMINER_TEMPLATE2\n"
			# PASSWORD
			[[ -n $LOLMINER_PASS2 ]] &&	conf+="--dualpass $LOLMINER_PASS2\n"
		done

		# WORKER
		[[ -n $LOLMINER_WORKER2 ]] && conf+="--dualworker $LOLMINER_WORKER2\n"

		# TLS and other options
		#check it! may not work!!!
		[[ $LOLMINER_TLS2 -eq 1 ]] && conf+="--dualtls 1\n"
	fi


	while read -r line; do
		[[ -z $line ]] && continue
		local tls_cnt=$(echo "$line" | grep -e "--tls" | awk '{print $2}' | tr ';' ' ' | wc -w)
		if [[ $tls_cnt -eq 1 ]]; then
			local tls_val=$(echo "$line" | grep -e "--tls" | awk '{print $2}')
			for ((i=0; i<$host_cnt; i++)); do
				conf+="--tls $tls_val\n"
			done
		else
			conf+="$line\n"
		fi
	done <<< "$LOLMINER_USER_CONFIG"

	conf+="--apiport $MINER_API_PORT\n"
	conf+=`cat $GLOBAL_CONFIG`"\n"

	echo -e "$conf" > $MINER_CONFIG
}
